mathtools.Ratio
===============

.. abjad-lineage:: abjad.tools.mathtools.Ratio.Ratio.Ratio

.. autoclass:: abjad.tools.mathtools.Ratio.Ratio.Ratio
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.mathtools.Ratio.Ratio.Ratio.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.count
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.index
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__add__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__contains__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__eq__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__ge__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__getitem__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__getslice__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__gt__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__hash__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__iter__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__le__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__len__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__lt__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__mul__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__ne__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__repr__
   :noindex:

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__rmul__
   :noindex:
